@@ -1,4 +1,6 @@
 import boto3
+import pandas as pd
+from io import StringIO as sio
 
 #####################################
 
@@ -12,6 +14,13 @@ def get_object(**kargs):
     obj = s3.Object(kargs.get('bucket'), kargs.get('key'))
     return obj.get()['Body'].read().decode('utf-8') 
 
+def get_csv_data_from_s3(**kargs):
+    s = kargs.get('session')
+    b = kargs.get('bucket')
+    k = kargs.get('key')
+    data = s3.get_assumed_object(s, bucket=b, key=k)
+    return pd.read_csv(sio(data), sep=","); 
+
 #####################################
 
 def put_object(s, **kargs):
@@ -20,5 +29,6 @@ def put_object(s, **kargs):
     b = kargs.get('bucket')
     r = kargs.get('region', 'us-east-1')
     s.client('s3', r).put_object(Body=d, Bucket=b, Key=k)
+    print(f'https://{b}.s3.amazonaws.com/{k}')
 
 #####################################
